#!/usr/bin/env python
# -*- encoding:utf-8 -*-

from .gamess import Gamess, GamessError

__version__ = "0.5.0"
__all__ = ["Gamess"]


del(gamess)
